package com.ruoyi.controller;

import java.util.Calendar;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.domain.EmployeeAnnualLeave;
import com.ruoyi.service.IEmployeeAnnualLeaveService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 员工年假Controller
 *
 * @author ruoyi
 * @date 2025-04-17
 */
@RestController
@RequestMapping("/system/annualleave")
public class EmployeeAnnualLeaveController extends BaseController
{
    @Autowired
    private IEmployeeAnnualLeaveService employeeAnnualLeaveService;

    /**
     * 查询员工年假列表
     */
    @PreAuthorize("@ss.hasPermi('psa:annualleave:list')")
    @GetMapping("/list")
    public TableDataInfo list(EmployeeAnnualLeave employeeAnnualLeave)
    {
        startPage();
        List<EmployeeAnnualLeave> list = employeeAnnualLeaveService.selectEmployeeAnnualLeaveList(employeeAnnualLeave);
        return getDataTable(list);
    }

    /**
     * 导出员工年假列表
     */
    @PreAuthorize("@ss.hasPermi('psa:annualleave:export')")
    @Log(title = "员工年假", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, EmployeeAnnualLeave employeeAnnualLeave)
    {
        List<EmployeeAnnualLeave> list = employeeAnnualLeaveService.selectEmployeeAnnualLeaveList(employeeAnnualLeave);
        ExcelUtil<EmployeeAnnualLeave> util = new ExcelUtil<EmployeeAnnualLeave>(EmployeeAnnualLeave.class);
        util.exportExcel(response, list, "员工年假数据");
    }

    /**
     * 获取员工年假详细信息
     */
    @PreAuthorize("@ss.hasPermi('psa:annualleave:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(employeeAnnualLeaveService.selectEmployeeAnnualLeaveById(id));
    }

    /**
     * 新增员工年假
     */
    @PreAuthorize("@ss.hasPermi('psa:annualleave:add')")
    @Log(title = "员工年假", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody EmployeeAnnualLeave employeeAnnualLeave)
    {
        return toAjax(employeeAnnualLeaveService.insertEmployeeAnnualLeave(employeeAnnualLeave));
    }

    /**
     * 修改员工年假
     */
    @PreAuthorize("@ss.hasPermi('psa:annualleave:edit')")
    @Log(title = "员工年假", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody EmployeeAnnualLeave employeeAnnualLeave)
    {
        return toAjax(employeeAnnualLeaveService.updateEmployeeAnnualLeave(employeeAnnualLeave));
    }

    /**
     * 删除员工年假
     */
    @PreAuthorize("@ss.hasPermi('psa:annualleave:remove')")
    @Log(title = "员工年假", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(employeeAnnualLeaveService.deleteEmployeeAnnualLeaveByIds(ids));
    }

}
