package com.ruoyi.service.impl;

import java.util.Calendar;
import java.util.List;

import com.ruoyi.system.service.ISysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mapper.EmployeeAnnualLeaveMapper;
import com.ruoyi.domain.EmployeeAnnualLeave;
import com.ruoyi.service.IEmployeeAnnualLeaveService;

/**
 * 员工年假Service业务层处理
 *
 * @author ruoyi
 * @date 2025-04-17
 */
@Service
public class EmployeeAnnualLeaveServiceImpl implements IEmployeeAnnualLeaveService
{
    @Autowired
    private EmployeeAnnualLeaveMapper employeeAnnualLeaveMapper;
    @Autowired
    private ISysUserService ISysUserService;

    /**
     * 查询员工年假
     *
     * @param id 员工年假主键
     * @return 员工年假
     */
    @Override
    public EmployeeAnnualLeave selectEmployeeAnnualLeaveById(Long id)
    {
        return employeeAnnualLeaveMapper.selectEmployeeAnnualLeaveById(id);
    }

    /**
     * 查询员工年假列表
     *
     * @param employeeAnnualLeave 员工年假
     * @return 员工年假
     */
    @Override
    public List<EmployeeAnnualLeave> selectEmployeeAnnualLeaveList(EmployeeAnnualLeave employeeAnnualLeave)
    {
        return employeeAnnualLeaveMapper.selectEmployeeAnnualLeaveList(employeeAnnualLeave);
    }

    /**
     * 新增员工年假
     *
     * @param employeeAnnualLeave 员工年假
     * @return 结果
     */
    @Override
    public int insertEmployeeAnnualLeave(EmployeeAnnualLeave employeeAnnualLeave)
    {
        // 设置默认年份为当前年份
        if (employeeAnnualLeave.getYear() == null) {
            Calendar calendar = Calendar.getInstance();
            employeeAnnualLeave.setYear((long) calendar.get(Calendar.YEAR));
        }

        // 设置默认年假天数为10天
        if (employeeAnnualLeave.getTotalDays() == null) {
            employeeAnnualLeave.setTotalDays(10L);
        }

        Object user = ISysUserService.selectUserByUserName(employeeAnnualLeave.getUname());
        if (user == null) {
            return -2; // 未找到对应员工
        }
        Long userId = ISysUserService.selectUserByUserName(employeeAnnualLeave.getUname()).getUserId();
        employeeAnnualLeave.setUserId(userId);

        // 验证已使用天数不能超过总天数
        if (employeeAnnualLeave.getUsedDays() > employeeAnnualLeave.getTotalDays()) {
            return -1; // 返回-1表示已使用天数超过总天数
        }

        // 自动计算剩余天数
        employeeAnnualLeave.setRemainingDays(employeeAnnualLeave.getTotalDays() - employeeAnnualLeave.getUsedDays());

        return employeeAnnualLeaveMapper.insertEmployeeAnnualLeave(employeeAnnualLeave);
    }

    /**
     * 修改员工年假
     *
     * @param employeeAnnualLeave 员工年假
     * @return 结果
     */
    @Override
    public int updateEmployeeAnnualLeave(EmployeeAnnualLeave employeeAnnualLeave)
    {
        // 设置默认年份为当前年份
        if (employeeAnnualLeave.getYear() == null) {
            Calendar calendar = Calendar.getInstance();
            employeeAnnualLeave.setYear((long) calendar.get(Calendar.YEAR));
        }

        // 设置默认年假天数为10天
        if (employeeAnnualLeave.getTotalDays() == null) {
            employeeAnnualLeave.setTotalDays(10L);
        }

        Object user = ISysUserService.selectUserByUserName(employeeAnnualLeave.getUname());
        if (user == null) {
            return -2; // 未找到对应员工
        }
        Long userId = ISysUserService.selectUserByUserName(employeeAnnualLeave.getUname()).getUserId();
        employeeAnnualLeave.setUserId(userId);

        // 验证已使用天数不能超过总天数
        if (employeeAnnualLeave.getUsedDays() > employeeAnnualLeave.getTotalDays()) {
            return -1; // 返回-1表示已使用天数超过总天数
        }

        // 自动计算剩余天数
        employeeAnnualLeave.setRemainingDays(employeeAnnualLeave.getTotalDays() - employeeAnnualLeave.getUsedDays());

        return employeeAnnualLeaveMapper.updateEmployeeAnnualLeave(employeeAnnualLeave);
    }

    /**
     * 批量删除员工年假
     *
     * @param ids 需要删除的员工年假主键
     * @return 结果
     */
    @Override
    public int deleteEmployeeAnnualLeaveByIds(Long[] ids)
    {
        return employeeAnnualLeaveMapper.deleteEmployeeAnnualLeaveByIds(ids);
    }

    /**
     * 删除员工年假信息
     *
     * @param id 员工年假主键
     * @return 结果
     */
    @Override
    public int deleteEmployeeAnnualLeaveById(Long id)
    {
        return employeeAnnualLeaveMapper.deleteEmployeeAnnualLeaveById(id);
    }
}
