package com.ruoyi.system.service.impl;

import java.util.*;
import java.util.stream.Collectors;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ProjectNumberGenerator;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.ProjectManage;
import com.ruoyi.system.domain.ProjectMember;
import com.ruoyi.system.domain.ProjectRepayment;
import com.ruoyi.system.mapper.*;
import com.ruoyi.system.service.IProjectManageService;
import com.ruoyi.system.service.IProjectMemberService;
import com.ruoyi.system.service.IProjectRepaymentService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 项目管理Service业务层处理
 *
 * @author wangjiancheng
 * @date 2025-02-26
 */
@Slf4j
@Service
public class ProjectManageServiceImpl implements IProjectManageService {
    @Autowired
    private ProjectManageMapper projectManageMapper;

    @Autowired
    private IProjectMemberService projectMemberService;

    @Autowired
    private IProjectRepaymentService projectRepaymentService;

    @Autowired
    private ProjectRepaymentMapper projectRepaymentMapper;

    @Autowired
    private ProjectMemberMapper projectMemberMapper;

    @Autowired
    private ProjectTypeMapper projectTypeMapper;

    @Autowired
    private ProjectAnnexMapper projectAnnexMapper;

    /**
     * 查询项目管理
     *
     * @param id 项目管理主键
     * @return 项目管理
     */
    @Override
    public ProjectManage selectProjectManageById(Long id) {
        ProjectManage projectManage = projectManageMapper.selectProjectManageById(id);
        if (!StringUtils.isEmpty(projectManage.getProjectMemberNames())){
            String projectMemberIdsStr = projectManage.getProjectMemberNames().trim();
            if (StringUtils.isEmpty(projectMemberIdsStr)) {
                // 设置为空列表
                projectManage.setProjectMemberIds(new ArrayList<>());
            } else {
                // 将字符串分割并转换为 Long 类型的列表
                projectManage.setProjectMemberIds(Arrays.stream(projectMemberIdsStr.split(","))
                        .map(Long::parseLong)
                        .collect(Collectors.toList()));
            }
        }else {
            projectManage.setProjectMemberIds(new ArrayList<>());
        }
        // 设置项目的回款详情
        projectManage.setRepaymentCount(projectRepaymentMapper.countProjectRepayment(id));
        ProjectRepayment projectRepayment = new ProjectRepayment();
        projectRepayment.setProjectId(id);
        projectManage.setRepaymentDetails(projectRepaymentService.selectProjectRepaymentList(projectRepayment));
        // 设置项目附件
        projectManage.setProjectAnnexList(projectAnnexMapper.selectProjectAnnexListByProjectId(id));
        return projectManage;
    }

    /**
     * 查询项目管理列表
     *
     * @param projectManage 项目管理
     * @return 项目管理
     */
    @Override
    public List<ProjectManage> selectProjectManageList(ProjectManage projectManage) {
        return projectManageMapper.selectProjectManageList(projectManage);
    }

    /*
    * 查询草稿箱项目
    * */
    @Override
    public List<ProjectManage> selectProjectManageListDraft(ProjectManage projectManage) {
        return projectManageMapper.selectProjectManageListDraft(projectManage);
    }

    /**
     * 新增项目管理
     *
     * @param projectManage 项目管理
     * @return 结果
     */
    @Override
    public int insertProjectManage(ProjectManage projectManage) {
        // 根据项目类型id，获取项目类型名称
        String[] projectTypeName =projectTypeMapper.selectDictLabel("project_type",
                        projectManage.getProjectType()).split("-");
        // 生成项目编号
        projectManage.setProjectNumber(ProjectNumberGenerator.generateProjectNumber(projectTypeName[0]));
        // 判断项目编号是否重复
        ProjectManage projectManageQuery = new ProjectManage();
        projectManageQuery.setProjectNumber(projectManage.getProjectNumber());
        if (!StringUtils.isEmpty(selectProjectManageList(projectManageQuery))) {
            return 0;
        }
        // 立项时间
        projectManage.setCreateDate(new Date());
        projectManage.setUpdateDate(new Date());
        projectManage.setDelFlag(String.valueOf(ProjectManage.NO_DELETE));
        //projectManage.setUpdateDate(new Date());
        // 事业部负责人
        projectManage.setDepartmentLeaderId(SecurityUtils.getUserId());
        // 新增项目信息
        int result= projectManageMapper.insertProjectManage(projectManage);
        if (result > 0){
            if (!StringUtils.isEmpty(projectManage.getProjectMemberIds())){
                System.out.println(projectManage.getProjectMemberIds());
                // 新增项目成员
                projectManage.getProjectMemberIds().forEach(memberId -> {
                    if (memberId != null){
                        ProjectMember projectMember = new ProjectMember();
                        projectMember.setProjectId(projectManage.getId());
                        projectMember.setUserId(memberId);
                        projectMemberService.insertProjectMember(projectMember);
                    }
                });
                //projectMemberService.batchInsertProjectMembers(projectManage.getId(), projectManage.getProjectMemberIds());
            }

            if ( !StringUtils.isEmpty(projectManage.getRepaymentDetails())){
                // 新增项目回款
                projectManage.getRepaymentDetails().forEach(projectRepayment -> {
                    projectRepayment.setProjectId(projectManage.getId());
                    projectRepaymentService.insertProjectRepayment(projectRepayment);
                });
            }
            if (!StringUtils.isEmpty(projectManage.getProjectAnnexList())){
                // 新增项目附件
                projectManage.getProjectAnnexList().forEach(projectAnnex -> {
                    projectAnnex.setProjectId(projectManage.getId());
                    projectAnnexMapper.insertProjectAnnex(projectAnnex);
                });
            }
        }
        return result;
    }

    /**
     * 修改项目管理
     *
     * @param projectManage 项目管理
     * @return 结果
     */
    @Override
    public int updateProjectManage(ProjectManage projectManage) {
        if (!StringUtils.isEmpty(projectManage.getProjectMemberIds())){
            projectMemberMapper.deleteProjectMemberByProjectId(projectManage.getId());
            // 项目成员
            projectManage.getProjectMemberIds().forEach(memberId -> {
                if (memberId != null){
                    // 同一项目下成员是否重复
                    //projectMemberMapper.deleteProjectMember(projectManage.getId(),memberId);
                    ProjectMember projectMember = new ProjectMember();
                    projectMember.setProjectId(projectManage.getId());
                    projectMember.setUserId(memberId);
                    projectMemberService.insertProjectMember(projectMember);
                }

            });
        }else {
            // 删除项目成员
            projectMemberMapper.deleteProjectMemberByProjectId(projectManage.getId());
        }

        if (!StringUtils.isEmpty(projectManage.getRepaymentDetails())){
            // 项目回款
            projectRepaymentMapper.deleteProjectRepaymentByProjectId(projectManage.getId());
            projectManage.getRepaymentDetails().forEach(projectRepayment -> {
                projectRepayment.setProjectId(projectManage.getId());
                projectRepaymentService.insertProjectRepayment(projectRepayment);

            });
        }else {
            // 删除项目回款
            projectRepaymentMapper.deleteProjectRepaymentByProjectId(projectManage.getId());
        }

        // 更新附件
        if (!StringUtils.isEmpty(projectManage.getProjectAnnexList())){
            projectAnnexMapper.deleteProjectAnnexesByProjectId(projectManage.getId());
            projectManage.getProjectAnnexList().forEach(projectAnnex -> {
                projectAnnex.setProjectId(projectManage.getId());
                projectAnnexMapper.insertProjectAnnex(projectAnnex);
            });
        }else{
            // 删除项目附件
            projectAnnexMapper.deleteProjectAnnexesByProjectId(projectManage.getId());
        }
        projectManage.setUpdateDate(DateUtils.getNowDate());
        return projectManageMapper.updateProjectManage(projectManage);
    }

    /**
     * 批量删除项目管理
     *
     * @param ids 需要删除的项目管理主键
     * @return 结果
     */
    @Override
    public int deleteProjectManageByIds(Long[] ids) {
        return projectManageMapper.deleteProjectManageByIds(ids);
    }

    /**
     * 删除项目管理信息
     *
     * @param id 项目管理主键
     * @return 结果
     */
    @Override
    public int deleteProjectManageById(Long id) {
        return projectManageMapper.deleteProjectManageById(id);
    }

    @Override
    public List<ProjectManage> selectProjectManageByProjectName(String projectName) {
        return projectManageMapper.selectProjectManageByProjectName(projectName);
    }

}
