package com.ruoyi.system.service.impl;

import java.util.List;

import com.ruoyi.system.mapper.ProjectMemberMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.domain.ProjectMember;
import com.ruoyi.system.service.IProjectMemberService;

/**
 * 项目成员Service业务层处理
 *
 * @author ruoyi
 * @date 2025-02-28
 */
@Service
public class ProjectMemberServiceImpl implements IProjectMemberService
{
    @Autowired
    private ProjectMemberMapper projectMemberMapper;

    /**
     * 查询项目成员
     *
     * @param projectId 项目成员主键
     * @return 项目成员
     */
    @Override
    public ProjectMember selectProjectMemberByProjectId(Long projectId)
    {
        return projectMemberMapper.selectProjectMemberByProjectId(projectId);
    }

    /**
     * 查询项目成员列表
     *
     * @param projectMember 项目成员
     * @return 项目成员
     */
    @Override
    public List<ProjectMember> selectProjectMemberList(ProjectMember projectMember)
    {
        return projectMemberMapper.selectProjectMemberList(projectMember);
    }

    /**
     * 新增项目成员
     *
     * @param projectMember 项目成员
     * @return 结果
     */
    @Override
    public int insertProjectMember(ProjectMember projectMember)
    {
        return projectMemberMapper.insertProjectMember(projectMember);
    }

    /**
     * 修改项目成员
     *
     * @param projectMember 项目成员
     * @return 结果
     */
    @Override
    public int updateProjectMember(ProjectMember projectMember)
    {
        return projectMemberMapper.updateProjectMember(projectMember);
    }

    /**
     * 批量删除项目成员
     *
     * @param projectIds 需要删除的项目成员主键
     * @return 结果
     */
    @Override
    public int deleteProjectMemberByProjectIds(Long[] projectIds)
    {
        return projectMemberMapper.deleteProjectMemberByProjectIds(projectIds);
    }

    /**
     * 删除项目成员信息
     *
     * @param projectId 项目成员主键
     * @return 结果
     */
    @Override
    public int deleteProjectMemberByProjectId(Long projectId)
    {
        return projectMemberMapper.deleteProjectMemberByProjectId(projectId);
    }

    @Override
    public void batchInsertProjectMembers(Long projectId, List<Long> memberIds) {
        if (memberIds != null && !memberIds.isEmpty()) {
            projectMemberMapper.batchInsertProjectMembers(projectId, memberIds);
        }
    }

    @Override
    public List<ProjectMember> selectEmployNameListByManagerId(String projectNumber, Long managerId) {
        return projectMemberMapper.selectEmployNameListByManagerId(projectNumber, managerId);
    }
}
